Struct Adc4Cfgr1
#[repr(transparent)]pub struct Adc4Cfgr1(pub u32);Expand description
Configuration register 1
Tuple Fields
0: u32Implementations
impl Adc4Cfgr1
impl Adc4Cfgr1
pub const fn dmacfg(&self) -> Adc4Dmacfg
pub const fn dmacfg(&self) -> Adc4Dmacfg
Direct memory access configuration
pub const fn set_dmacfg(&mut self, val: Adc4Dmacfg)
pub const fn set_dmacfg(&mut self, val: Adc4Dmacfg)
Direct memory access configuration
pub const fn scandir(&self) -> Adc4Scandir
pub const fn scandir(&self) -> Adc4Scandir
Scan sequence direction
pub const fn set_scandir(&mut self, val: Adc4Scandir)
pub const fn set_scandir(&mut self, val: Adc4Scandir)
Scan sequence direction
pub const fn set_extsel(&mut self, val: u8)
pub const fn set_extsel(&mut self, val: u8)
External trigger selection
pub const fn ovrmod(&self) -> bool
pub const fn ovrmod(&self) -> bool
Overrun management mode (0: ADC_DR is preserved when an overrun is detected, 1: ADC_DR is overwritten with the last conversion result)
pub const fn set_ovrmod(&mut self, val: bool)
pub const fn set_ovrmod(&mut self, val: bool)
Overrun management mode (0: ADC_DR is preserved when an overrun is detected, 1: ADC_DR is overwritten with the last conversion result)
pub const fn set_discen(&mut self, val: bool)
pub const fn set_discen(&mut self, val: bool)
Discontinuous mode
pub const fn chselrmod(&self) -> bool
pub const fn chselrmod(&self) -> bool
Mode selection of the ADC_CHSELR register (0: one bit per channel, 1: fully configurable sequencer)
pub const fn set_chselrmod(&mut self, val: bool)
pub const fn set_chselrmod(&mut self, val: bool)
Mode selection of the ADC_CHSELR register (0: one bit per channel, 1: fully configurable sequencer)
pub const fn awd1sgl(&self) -> bool
pub const fn awd1sgl(&self) -> bool
Enable the analog watchdog 1 on a single channel (1) or on all channels (0)
pub const fn set_awd1sgl(&mut self, val: bool)
pub const fn set_awd1sgl(&mut self, val: bool)
Enable the analog watchdog 1 on a single channel (1) or on all channels (0)
pub const fn set_awd1en(&mut self, val: bool)
pub const fn set_awd1en(&mut self, val: bool)
Analog watchdog 1 enable
pub const fn set_awd1ch(&mut self, val: u8)
pub const fn set_awd1ch(&mut self, val: u8)
Analog watchdog 1 channel selection